@@ -1,19 +1,21 @@
 use itertools::Itertools;
 use tombi_ast::AstNode;
 use tombi_comment_directive::value::{
-    TableCommonLintRules, TableFormatRules, TombiValueDirectiveContent,
+    TableCommonFormatRules, TableCommonLintRules, TombiValueDirectiveContent,
 };
 use tombi_schema_store::{CurrentSchema, SchemaContext};
 use tombi_syntax::SyntaxElement;
 
-use crate::rule::{inline_table_comma_trailing_comment, table_keys_order::sorted_accessors};
+use crate::rule::{inline_table_comma_trailing_comment, table_keys_order::get_sorted_accessors};
 
 pub async fn inline_table_keys_order<'a>(
     value: &'a tombi_document_tree::Value,
     key_values_with_comma: Vec<(tombi_ast::KeyValue, Option<tombi_ast::Comma>)>,
     current_schema: Option<&'a CurrentSchema<'a>>,
     schema_context: &'a SchemaContext<'a>,
-    comment_directive: Option<TombiValueDirectiveContent<TableFormatRules, TableCommonLintRules>>,
+    comment_directive: Option<
+        TombiValueDirectiveContent<TableCommonFormatRules, TableCommonLintRules>,
+    >,
 ) -> Vec<crate::Change> {
     if key_values_with_comma.is_empty() {
         return Vec::with_capacity(0);
@@ -43,7 +45,7 @@ pub async fn inline_table_keys_order<'a>(
         SyntaxElement::Node(key_values_with_comma.last().unwrap().0.syntax().clone()),
     );
 
-    let mut sorted_key_values_with_comma = sorted_accessors(
+    let Some(mut sorted_key_values_with_comma) = get_sorted_accessors(
         value,
         &[],
         key_values_with_comma
@@ -60,7 +62,10 @@ pub async fn inline_table_keys_order<'a>(
         schema_context,
         order,
     )
-    .await;
+    .await
+    else {
+        return Vec::with_capacity(0);
+    };
 
     if let Some((_, comma)) = sorted_key_values_with_comma.last_mut() {
         if !is_last_comma {
