@@ -1,15 +1,11 @@
 use std::path::PathBuf;
 
 use clap::Parser;
-use clap_verbosity_flag::{InfoLevel, Verbosity};
 use tombi_diagnostic::{printer::Pretty, Diagnostic, Print};
 use tracing_subscriber::prelude::*;
 
 #[derive(clap::Parser)]
-pub struct Args {
-    #[command(flatten)]
-    verbose: Verbosity<InfoLevel>,
-}
+pub struct Args {}
 
 pub fn project_root_path() -> PathBuf {
     let dir = std::env::var("CARGO_MANIFEST_DIR")
@@ -27,12 +23,9 @@ pub fn source_file() -> PathBuf {
 }
 
 fn main() -> Result<(), Box<dyn std::error::Error>> {
-    let args = Args::parse_from(std::env::args_os());
+    let _args = Args::parse_from(std::env::args_os());
 
     tracing_subscriber::registry()
-        .with(tracing_subscriber::EnvFilter::from(
-            args.verbose.log_level_filter().to_string(),
-        ))
         .with(tracing_subscriber::fmt::layer().pretty().without_time())
         .init();
 
