@@ -6,6 +6,7 @@ use tombi_text::{Position, Range};
 use tower_lsp::lsp_types::{
     notification::PublishDiagnostics, DocumentFormattingParams, PublishDiagnosticsParams, TextEdit,
 };
+use unicode_segmentation::UnicodeSegmentation;
 
 use crate::{backend::Backend, config_manager::ConfigSchemaStore};
 
@@ -45,12 +46,12 @@ pub async fn handle_formatting(
             MatchResult::Matched => {}
             MatchResult::IncludeNotMatched => {
                 tracing::info!(
-                    "skip {text_document_path:?} because it is not in config.files.include"
+                    "Skip {text_document_path:?} because it is not in config.files.include"
                 );
                 return Ok(None);
             }
             MatchResult::ExcludeMatched => {
-                tracing::info!("skip {text_document_path:?} because it is in config.files.exclude");
+                tracing::info!("Skip {text_document_path:?} because it is in config.files.exclude");
                 return Ok(None);
             }
         }
@@ -66,11 +67,11 @@ pub async fn handle_formatting(
         .ok()
         .flatten();
 
-    let document_tombi_comment_directive =
-        tombi_comment_directive::get_document_tombi_comment_directive(&root).await;
+    let tombi_document_comment_directive =
+        tombi_validator::comment_directive::get_tombi_document_comment_directive(&root).await;
     let (toml_version, _) = backend
         .source_toml_version(
-            document_tombi_comment_directive,
+            tombi_document_comment_directive,
             source_schema.as_ref(),
             &config,
         )
@@ -93,11 +94,11 @@ pub async fn handle_formatting(
     .format(&document_source.text)
     .await
     {
-        Ok(new_text) => {
-            if new_text != document_source.text {
+        Ok(formatted) => {
+            if document_source.text != formatted {
                 let edits =
-                    compute_text_edits(&document_source.text, &new_text, &formatter_definitions);
-                document_source.text = new_text.clone();
+                    compute_text_edits(&document_source.text, &formatted, &formatter_definitions);
+                document_source.text = formatted.clone();
 
                 return Ok(Some(edits));
             } else {
@@ -113,7 +114,7 @@ pub async fn handle_formatting(
             }
         }
         Err(diagnostics) => {
-            tracing::error!("failed to format");
+            tracing::error!("Failed to format");
             backend
                 .client
                 .send_notification::<PublishDiagnostics>(PublishDiagnosticsParams {
@@ -196,7 +197,7 @@ fn compute_text_edits(
         let last_line = old_lines.last().unwrap_or(&"");
         Position::new(
             (old_lines.len() - 1) as u32,
-            last_line.chars().count() as u32,
+            UnicodeSegmentation::graphemes(*last_line, true).count() as u32,
         )
     };
 
