@@ -41,7 +41,7 @@ mod completion_labels {
 
         test_completion_labels! {
             #[tokio::test]
-            async fn tombi_comment_schema_directive(
+            async fn schema_comment_directive(
                 "#:█",
                 Schema(tombi_schema_path()),
             ) -> Ok(["schema", "tombi"]);
@@ -57,7 +57,7 @@ mod completion_labels {
 
         test_completion_labels! {
             #[tokio::test]
-            async fn tombi_comment_schema_directive_and_comment(
+            async fn schema_comment_directive_and_comment(
                 r#"
                 #:schema https://json.schemastore.org/tombi.json
                 # █
@@ -68,7 +68,28 @@ mod completion_labels {
 
         test_completion_labels! {
             #[tokio::test]
-            async fn tombi_comment_schema_directive_and_colon(
+            async fn tombi_comment_directive_toml_version(
+                r#"
+                #:tombi toml-version█
+                "#,
+                Schema(tombi_schema_path()),
+            ) -> Ok([".", "="]);
+        }
+
+        test_completion_labels! {
+            #[tokio::test]
+            async fn space_tombi_comment_directive_toml_version(
+                r#"
+                    #:tombi   toml-version█
+                key = "value"
+                "#,
+                Schema(tombi_schema_path()),
+            ) -> Ok([".", "="]);
+        }
+
+        test_completion_labels! {
+            #[tokio::test]
+            async fn tombi_comment_directive_and_colon(
                 r#"
                 #:schema https://json.schemastore.org/tombi.json
                 #:█
@@ -162,6 +183,38 @@ mod completion_labels {
             ]);
         }
 
+        test_completion_labels! {
+            #[tokio::test]
+            async fn tombi_used_toml_version_and_space(
+                r#"
+                toml-version = "v1.0.0" █
+                "#,
+                Schema(tombi_schema_path()),
+            ) -> Ok([]);
+        }
+
+        test_completion_labels! {
+            #[tokio::test]
+            async fn tombi_lsp_completion_enabled_true_and_space(
+                r#"
+                [lsp]
+                completion.enabled = true █
+                "#,
+                Schema(tombi_schema_path()),
+            ) -> Ok([]);
+        }
+
+        test_completion_labels! {
+            #[tokio::test]
+            async fn tombi_lint_rules_key_empty_equal_warn_and_space(
+                r#"
+                [lint.rules]
+                key-empty = "warn" █
+                "#,
+                Schema(tombi_schema_path()),
+            ) -> Ok([]);
+        }
+
         test_completion_labels! {
             #[tokio::test]
             async fn tombi_empty_bracket(
@@ -409,6 +462,7 @@ mod completion_labels {
                 Schema(tombi_schema_path()),
             ) -> Ok([
                 "code-action",
+                "diagnostic",
                 "diagnostics",
                 "document-link",
                 "formatting",
@@ -416,6 +470,7 @@ mod completion_labels {
                 "goto-definition",
                 "goto-type-definition",
                 "hover",
+                "workspace-diagnostic",
             ]);
         }
 
@@ -431,12 +486,14 @@ mod completion_labels {
                 Schema(tombi_schema_path()),
             ) -> Ok([
                 "code-action",
+                "diagnostic",
                 "diagnostics",
                 "document-link",
                 "goto-declaration",
                 "goto-definition",
                 "goto-type-definition",
                 "hover",
+                "workspace-diagnostic",
             ]);
         }
 
@@ -453,12 +510,14 @@ mod completion_labels {
                 Schema(tombi_schema_path()),
             ) -> Ok([
                 "completion",
+                "diagnostic",
                 "diagnostics",
                 "document-link",
                 "goto-declaration",
                 "goto-definition",
                 "goto-type-definition",
                 "hover",
+                "workspace-diagnostic",
             ]);
         }
 
@@ -546,6 +605,19 @@ mod completion_labels {
                 "''",
             ]);
         }
+
+        test_completion_labels! {
+            #[tokio::test]
+            async fn tombi_toml_version_v1_0_0_comment_directive(
+                r#"
+                toml-version = "v1.0.0" # tombi:█
+                "#,
+                Schema(tombi_schema_path()),
+            ) -> Ok([
+                "format",
+                "lint",
+            ]);
+        }
     }
 
     mod pyproject_schema {
@@ -626,7 +698,7 @@ mod completion_labels {
 
         test_completion_labels! {
             #[tokio::test]
-            async fn pyproject_project_dynamic_array_with_values(
+            async fn pyproject_project_dynamic_array_in_values_with_last_comma(
                 // Check `unique_items = true` case.
                 r#"
                 [project]
@@ -756,6 +828,133 @@ mod completion_labels {
                 Schema(pyproject_schema_path()),
             ) -> Ok(AnyValue);
         }
+
+        test_completion_labels! {
+            #[tokio::test]
+            async fn pyproject_tool_maturin_include_array(
+                r#"
+                [tool.maturin]
+                bindings = "bin"
+                include = [
+                    █
+                    { path = "json.schemastore.org/**/*.json", format = "sdist" },
+                ]
+                "#,
+                Schema(pyproject_schema_path()),
+            ) -> Ok([
+                "format",
+                "path",
+                "\"\"",
+                "''",
+                "{}",
+            ]);
+        }
+
+        test_completion_labels! {
+            #[tokio::test]
+            async fn pyproject_project_leading_comments_directive_newline_name_eq_tombi(
+                r#"
+                # tombi: lint.rules█
+                [project]
+                name = "tombi"
+                "#,
+                Schema(pyproject_schema_path()),
+            ) -> Ok([
+                ".",
+                "="
+            ]);
+        }
+
+        test_completion_labels! {
+            #[tokio::test]
+            async fn pyproject_project_comment_directive_newline_name_eq_tombi(
+                r#"
+                [project]
+                # tombi: lint.rules█
+
+                name = "tombi"
+                "#,
+                Schema(pyproject_schema_path()),
+            ) -> Ok([
+                ".",
+                "="
+            ]);
+        }
+
+        test_completion_labels! {
+            #[tokio::test]
+            async fn pyproject_project_trailing_comment_directive_newline_name_eq_tombi(
+                r#"
+                [project]  # tombi: lint.rules█
+
+                name = "tombi"
+                "#,
+                Schema(pyproject_schema_path()),
+            ) -> Ok([
+                ".",
+                "="
+            ]);
+        }
+
+        test_completion_labels! {
+            #[tokio::test]
+            async fn pyproject_project_comment_directive_name_eq_tombi(
+                r#"
+                [project]
+                # tombi: lint.rules█
+                name = "tombi"
+                "#,
+                Schema(pyproject_schema_path()),
+            ) -> Ok([
+                ".",
+                "="
+            ]);
+        }
+
+        test_completion_labels! {
+            #[tokio::test]
+            async fn pyproject_project_name_eq_tombi_comment_directive(
+                r#"
+                [project]
+                name = "tombi" # tombi: lint█
+                "#,
+                Schema(pyproject_schema_path()),
+            ) -> Ok([
+                ".",
+                "="
+            ]);
+        }
+
+        test_completion_labels! {
+            #[tokio::test]
+            async fn pyproject_project_description_comment_directive(
+                r#"
+                [project]
+                description = "🦅 TOML Toolkit 🦅 " # tombi: lint█
+                "#,
+                Schema(pyproject_schema_path()),
+            ) -> Ok([
+                ".",
+                "="
+            ]);
+        }
+
+        test_completion_labels! {
+            #[tokio::test]
+            async fn pyproject_project_dependencies_eq_array_comment_directive(
+                r#"
+                [project]
+                name = "tombi"
+                dependencies = [
+                    # tombi: lint█
+                ]
+                "#,
+                Schema(pyproject_schema_path()),
+            ) -> Ok([
+                ".",
+                "="
+            ]);
+        }
     }
 
     mod cargo_schema {
@@ -902,6 +1101,30 @@ mod completion_labels {
             ]);
         }
 
+        test_completion_labels! {
+         #[tokio::test]
+            async fn cargo_dependencies_tombi_date_time_features_with_workspace_eq_true_comma(
+                r#"
+                [dependencies]
+                tombi-date-time = { workspace = true, █ }
+                "#,
+                Source(project_root_path().join("crates/subcrate/Cargo.toml")),
+                Schema(cargo_schema_path()),
+            ) -> Ok([
+                "branch",
+                "default-features",
+                "features",
+                "git",
+                "optional",
+                "package",
+                "path",
+                "registry",
+                "rev",
+                "tag",
+                "version",
+            ]);
+        }
+
         test_completion_labels! {
             #[tokio::test]
             async fn cargo_dependencies_tombi_date_time_features_with_workspace(
@@ -1108,8 +1331,9 @@ mod completion_labels {
                 "local-date",
                 "local-date-time",
                 "local-time",
-                "object",
                 "offset-date-time",
+                "string",
+                "table",
             ]);
         }
 
@@ -1130,8 +1354,9 @@ mod completion_labels {
                 "local-date",
                 "local-date-time",
                 "local-time",
-                "object",
                 "offset-date-time",
+                "string",
+                "table",
             ]);
         }
     }
@@ -1405,7 +1630,7 @@ mod completion_labels {
                             .cmp(&b.sort_text.as_ref().unwrap_or(&b.label))
                     })
                     .map(|item| item.label)
-                    .collect::<Vec<_>>();
+                    .collect_vec();
 
                 pretty_assertions::assert_eq!(
                     labels,
@@ -1674,7 +1899,7 @@ mod completion_labels {
                             .cmp(&b.sort_text.as_ref().unwrap_or(&b.label))
                     })
                     .map(|item| item.label)
-                    .collect::<Vec<_>>();
+                    .collect_vec();
 
                 pretty_assertions::assert_eq!(
                     labels,
