@@ -1,4 +1,4 @@
-use tombi_comment_directive::value::{BooleanCommonLintRules, BooleanFormatRules};
+use tombi_comment_directive::value::{BooleanCommonFormatRules, BooleanCommonLintRules};
 use tombi_document_tree::ValueImpl;
 use tombi_future::{BoxFuture, Boxable};
 use tombi_schema_store::ValueSchema;
@@ -21,7 +21,7 @@ impl Validate for tombi_document_tree::Boolean {
             let mut total_diagnostics = vec![];
             let value_rules = if let Some(comment_directives) = self.comment_directives() {
                 let (value_rules, diagnostics) = get_tombi_key_table_value_rules_and_diagnostics::<
-                    BooleanFormatRules,
+                    BooleanCommonFormatRules,
                     BooleanCommonLintRules,
                 >(comment_directives, accessors)
                 .await;
