@@ -1,4 +1,4 @@
-use tombi_comment_directive::value::{LocalDateCommonLintRules, LocalDateFormatRules};
+use tombi_comment_directive::value::{LocalDateCommonFormatRules, LocalDateCommonLintRules};
 use tombi_document_tree::{LocalDate, ValueImpl};
 use tombi_future::{BoxFuture, Boxable};
 use tombi_schema_store::ValueSchema;
@@ -21,7 +21,7 @@ impl Validate for LocalDate {
             let mut total_diagnostics = vec![];
             let value_rules = if let Some(comment_directives) = self.comment_directives() {
                 let (value_rules, diagnostics) = get_tombi_key_table_value_rules_and_diagnostics::<
-                    LocalDateFormatRules,
+                    LocalDateCommonFormatRules,
                     LocalDateCommonLintRules,
                 >(comment_directives, accessors)
                 .await;
