@@ -1,3 +1,6 @@
+use itertools::Itertools;
+use nu_ansi_term::{Color, Style};
+use similar::{ChangeTag, TextDiff};
 use tokio::io::{AsyncReadExt, AsyncSeekExt, AsyncWriteExt};
 use tombi_config::{FormatOptions, TomlVersion};
 use tombi_diagnostic::{printer::Pretty, Diagnostic, Print};
@@ -20,6 +23,10 @@ pub struct Args {
     #[arg(long, default_value_t = false)]
     check: bool,
 
+    /// Show format changes
+    #[arg(long, default_value_t = false)]
+    diff: bool,
+
     /// Filename to use when reading from stdin
     ///
     /// This is useful for determining which JSON Schema should be applied, for more rich formatting.
@@ -135,6 +142,7 @@ where
                     printer,
                     toml_version,
                     args.check,
+                    args.diff,
                     &format_options,
                     &schema_store,
                 )
@@ -147,7 +155,7 @@ where
             }
             FileSearch::Files(files) => {
                 let mut tasks = tokio::task::JoinSet::new();
-
+                let mut errors = Vec::new();
                 for file in files {
                     match file {
                         Ok(source_path) => {
@@ -162,9 +170,10 @@ where
                                         format_file(
                                             file,
                                             printer,
-                                            Some(&source_path),
+                                            &source_path,
                                             toml_version,
                                             args.check,
+                                            args.diff,
                                             &format_options,
                                             &schema_store,
                                         )
@@ -200,7 +209,8 @@ where
                                 not_needed_num += 1;
                             }
                         }
-                        Ok(Err(_)) => {
+                        Ok(Err(error)) => {
+                            errors.push(error);
                             error_num += 1;
                         }
                         Err(e) => {
@@ -209,6 +219,12 @@ where
                         }
                     }
                 }
+
+                if !errors.is_empty() {
+                    for error in errors {
+                        error.print(&mut printer);
+                    }
+                }
             }
         };
 
@@ -224,112 +240,167 @@ async fn format_stdin<P>(
     mut printer: P,
     toml_version: TomlVersion,
     check: bool,
+    diff: bool,
     format_options: &FormatOptions,
     schema_store: &tombi_schema_store::SchemaStore,
-) -> Result<bool, ()>
+) -> Result<bool, crate::Error>
 where
     Diagnostic: Print<P>,
     crate::Error: Print<P>,
 {
     let mut source = String::new();
     let format_definitions = FormatDefinitions::default();
-    if file.read_to_string(&mut source).await.is_ok() {
-        match tombi_formatter::Formatter::new(
-            toml_version,
-            &format_definitions,
-            format_options,
-            file.source().map(itertools::Either::Right),
-            schema_store,
-        )
-        .format(&source)
-        .await
-        {
-            Ok(formatted) => {
-                if check {
-                    if source != formatted {
-                        crate::error::NotFormattedError::from(file.source())
-                            .into_error()
-                            .print(&mut printer);
-                        Err(())
-                    } else {
-                        Ok(false)
-                    }
-                } else {
-                    print!("{formatted}");
-                    Ok(source != formatted)
-                }
+    if let Err(err) = file.read_to_string(&mut source).await {
+        return Err(crate::Error::Io(err));
+    }
+    match tombi_formatter::Formatter::new(
+        toml_version,
+        &format_definitions,
+        format_options,
+        file.source().map(itertools::Either::Right),
+        schema_store,
+    )
+    .format(&source)
+    .await
+    {
+        Ok(formatted) => {
+            let has_diff = source != formatted;
+            if has_diff && diff {
+                tracing::info!("Found format changes in stdin");
+                eprint_diff(&source, &formatted);
             }
-            Err(diagnostics) => {
-                print!("{source}");
-                diagnostics.print(&mut printer);
-                Err(())
+            if check {
+                if has_diff {
+                    Err(crate::error::NotFormattedError::from(file.source()).into_error())
+                } else {
+                    Ok(false)
+                }
+            } else {
+                print!("{formatted}");
+                Ok(has_diff)
             }
         }
-    } else {
-        Err(())
+        Err(diagnostics) => {
+            print!("{source}");
+            diagnostics.print(&mut printer);
+            Err(crate::Error::StdinParseFailed)
+        }
     }
 }
 
 async fn format_file<P>(
     mut file: FormatFile,
     mut printer: P,
-    source_path: Option<&std::path::Path>,
+    source_path: &std::path::Path,
     toml_version: TomlVersion,
     check: bool,
+    diff: bool,
     format_options: &FormatOptions,
     schema_store: &tombi_schema_store::SchemaStore,
-) -> Result<bool, ()>
+) -> Result<bool, crate::Error>
 where
     Diagnostic: Print<P>,
     crate::Error: Print<P>,
 {
     let mut source = String::new();
     let format_definitions = FormatDefinitions::default();
-    if file.read_to_string(&mut source).await.is_ok() {
-        match tombi_formatter::Formatter::new(
-            toml_version,
-            &format_definitions,
-            format_options,
-            source_path.map(itertools::Either::Right),
-            schema_store,
-        )
-        .format(&source)
-        .await
-        {
-            Ok(formatted) => {
-                if source != formatted {
-                    if check {
-                        crate::error::NotFormattedError::from(file.source())
-                            .into_error()
-                            .print(&mut printer);
+    if let Err(err) = file.read_to_string(&mut source).await {
+        return Err(crate::Error::Io(err));
+    }
+    match tombi_formatter::Formatter::new(
+        toml_version,
+        &format_definitions,
+        format_options,
+        Some(itertools::Either::Right(source_path)),
+        schema_store,
+    )
+    .format(&source)
+    .await
+    {
+        Ok(formatted) => {
+            if source != formatted {
+                if diff {
+                    tracing::info!("Found format changes in {:?}", source_path);
+                    eprint_diff(&source, &formatted);
+                }
+                if check {
+                    Err(crate::error::NotFormattedError::from(file.source()).into_error())
+                } else {
+                    if let Err(err) = file.reset().await {
+                        Err(crate::Error::Io(err))
                     } else {
-                        if let Err(err) = file.reset().await {
-                            crate::Error::Io(err).print(&mut printer);
-                            return Err(());
-                        }
                         match file.write_all(formatted.as_bytes()).await {
-                            Ok(_) => return Ok(true),
-                            Err(err) => {
-                                crate::Error::Io(err).print(&mut printer);
-                            }
+                            Ok(_) => Ok(true),
+                            Err(err) => Err(crate::Error::Io(err)),
                         }
                     }
-                } else {
-                    return Ok(false);
                 }
-            }
-            Err(diagnostics) => if let Some(source_path) = source_path {
-                diagnostics
-                    .into_iter()
-                    .map(|diagnostic| diagnostic.with_source_file(source_path))
-                    .collect()
             } else {
-                diagnostics
+                Ok(false)
+            }
+        }
+        Err(diagnostics) => {
+            diagnostics
+                .into_iter()
+                .map(|diagnostic| diagnostic.with_source_file(source_path))
+                .collect_vec()
+                .print(&mut printer);
+            Err(crate::Error::FileParseFailed(source_path.to_owned()))
+        }
+    }
+}
+
+struct Line(Option<usize>);
+
+impl std::fmt::Display for Line {
+    fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
+        match self.0 {
+            None => write!(f, "    "),
+            Some(idx) => write!(f, "{:<4}", idx + 1),
+        }
+    }
+}
+
+fn eprint_diff(source: &str, formatted: &str) {
+    let diff = TextDiff::from_lines(source, formatted);
+    const INDENT: &str = "        ";
+
+    for (idx, group) in diff.grouped_ops(3).iter().enumerate() {
+        if idx > 0 {
+            eprintln!("{INDENT}{:-^1$}", "-", 89);
+        }
+        for op in group {
+            for change in diff.iter_inline_changes(op) {
+                let (sign, s) = match change.tag() {
+                    ChangeTag::Delete => ("-", Style::new().fg(Color::Red)),
+                    ChangeTag::Insert => ("+", Style::new().fg(Color::Green)),
+                    ChangeTag::Equal => (" ", Style::new().fg(Color::White).dimmed()),
+                };
+                eprint!(
+                    "{INDENT}{}{} |{}",
+                    Style::new()
+                        .fg(Color::White)
+                        .dimmed()
+                        .paint(format!("{}", Line(change.old_index()))),
+                    Style::new()
+                        .fg(Color::White)
+                        .dimmed()
+                        .paint(format!("{}", Line(change.new_index()))),
+                    s.bold().paint(sign),
+                );
+                for (emphasized, value) in change.iter_strings_lossy() {
+                    if emphasized {
+                        eprint!("{}", s.underline().on(Color::Black).paint(value));
+                    } else {
+                        eprint!("{}", s.paint(value));
+                    }
+                }
+                if change.missing_newline() {
+                    eprintln!();
+                }
             }
-            .print(&mut printer),
         }
     }
-    Err(())
 }
 
 enum FormatFile {
